@@ -30,7 +30,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "pathsearch.h"
 
 #ifndef OCTAVE_CANONICAL_HOST_TYPE
-#define OCTAVE_CANONICAL_HOST_TYPE "i386-unknown-openbsd4.3"
+#define OCTAVE_CANONICAL_HOST_TYPE "alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_DEFAULT_PAGER
@@ -38,7 +38,7 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_ARCHLIBDIR
-#define OCTAVE_ARCHLIBDIR "/usr/local/libexec/octave/3.0.0/exec/i386-unknown-openbsd4.3"
+#define OCTAVE_ARCHLIBDIR "/usr/local/libexec/octave/3.0.1/exec/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_BINDIR
@@ -58,11 +58,11 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_FCNFILEDIR
-#define OCTAVE_FCNFILEDIR "/usr/local/share/octave/3.0.0/m"
+#define OCTAVE_FCNFILEDIR "/usr/local/share/octave/3.0.1/m"
 #endif
 
 #ifndef OCTAVE_IMAGEDIR
-#define OCTAVE_IMAGEDIR "/usr/local/share/octave/3.0.0/imagelib"
+#define OCTAVE_IMAGEDIR "/usr/local/share/octave/3.0.1/imagelib"
 #endif
 
 #ifndef OCTAVE_INCLUDEDIR
@@ -94,11 +94,11 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_LOCALAPIOCTFILEDIR
-#define OCTAVE_LOCALAPIOCTFILEDIR "/usr/local/libexec/octave/site/oct/api-v32/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALAPIOCTFILEDIR "/usr/local/libexec/octave/site/oct/api-v32/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_LOCALARCHLIBDIR
-#define OCTAVE_LOCALARCHLIBDIR "/usr/local/libexec/octave/site/exec/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALARCHLIBDIR "/usr/local/libexec/octave/site/exec/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_LOCALFCNFILEDIR
@@ -106,7 +106,7 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_LOCALOCTFILEDIR
-#define OCTAVE_LOCALOCTFILEDIR "/usr/local/libexec/octave/site/oct/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALOCTFILEDIR "/usr/local/libexec/octave/site/oct/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_LOCALSTARTUPFILEDIR
@@ -114,19 +114,19 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_LOCALAPIARCHLIBDIR
-#define OCTAVE_LOCALAPIARCHLIBDIR "/usr/local/libexec/octave/api-v32/site/exec/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALAPIARCHLIBDIR "/usr/local/libexec/octave/api-v32/site/exec/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_LOCALVERARCHLIBDIR
-#define OCTAVE_LOCALVERARCHLIBDIR "/usr/local/libexec/octave/3.0.0/site/exec/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALVERARCHLIBDIR "/usr/local/libexec/octave/3.0.1/site/exec/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_LOCALVERFCNFILEDIR
-#define OCTAVE_LOCALVERFCNFILEDIR "/usr/local/share/octave/3.0.0/site/m"
+#define OCTAVE_LOCALVERFCNFILEDIR "/usr/local/share/octave/3.0.1/site/m"
 #endif
 
 #ifndef OCTAVE_LOCALVEROCTFILEDIR
-#define OCTAVE_LOCALVEROCTFILEDIR "/usr/local/libexec/octave/3.0.0/site/oct/i386-unknown-openbsd4.3"
+#define OCTAVE_LOCALVEROCTFILEDIR "/usr/local/libexec/octave/3.0.1/site/oct/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_MAN1DIR
@@ -142,11 +142,11 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_OCTFILEDIR
-#define OCTAVE_OCTFILEDIR "/usr/local/libexec/octave/3.0.0/oct/i386-unknown-openbsd4.3"
+#define OCTAVE_OCTFILEDIR "/usr/local/libexec/octave/3.0.1/oct/alpha-unknown-openbsd4.4"
 #endif
 
 #ifndef OCTAVE_OCTINCLUDEDIR
-#define OCTAVE_OCTINCLUDEDIR "/usr/local/include/octave-3.0.0"
+#define OCTAVE_OCTINCLUDEDIR "/usr/local/include/octave-3.0.1"
 #endif
 
 #ifndef OCTAVE_OCTLIBDIR
@@ -158,7 +158,7 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #ifndef OCTAVE_STARTUPFILEDIR
-#define OCTAVE_STARTUPFILEDIR "/usr/local/share/octave/3.0.0/m/startup"
+#define OCTAVE_STARTUPFILEDIR "/usr/local/share/octave/3.0.1/m/startup"
 #endif
 
 #ifndef OCTAVE_RELEASE
